@@ -27,11 +27,12 @@ pip install cloudcomponents.cdk-codepipeline-check-parameter-action
 ## How to use
 
 ```python
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { Pipeline, Artifact } from '@aws-cdk/aws-codepipeline';
-import { CodeCommitSourceAction } from '@aws-cdk/aws-codepipeline-actions';
 import { CodePipelineCheckParameterAction } from '@cloudcomponents/cdk-codepipeline-check-parameter-action';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { Pipeline, Artifact } from 'aws-cdk-lib/aws-codepipeline';
+import { CodeCommitSourceAction } from 'aws-cdk-lib/aws-codepipeline-actions';
+import { Construct } from 'constructs';
 
 export class CodePipelineCheckParameterActionStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
@@ -103,7 +104,7 @@ import aws_cdk.aws_codepipeline_actions
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class CheckParameterFunction(
@@ -113,7 +114,7 @@ class CheckParameterFunction(
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         parameter_name: builtins.str,
@@ -227,7 +228,7 @@ class CodePipelineCheckParameterAction(
     @jsii.member(jsii_name="bound")
     def _bound(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         _stage: aws_cdk.aws_codepipeline.IStage,
         *,
         bucket: aws_cdk.aws_s3.IBucket,
