@@ -8,18 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_codepipeline._jsii
-import aws_cdk.aws_codepipeline_actions._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-codepipeline-check-parameter-action",
-    "1.50.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-codepipeline-check-parameter-action@1.50.0.jsii.tgz",
+    "cdk-codepipeline-check-parameter-action@2.0.0.jsii.tgz",
 )
 
 __all__ = [
